<p>
  <picture>
    <!-- light mode logo -->
    <source media='(prefers-color-scheme: light)' srcset='https://raw.githubusercontent.com/easyscience/assets-branding/refs/heads/master/easyutilities/logos/light.svg'>
    <!-- dark mode logo -->
    <source media='(prefers-color-scheme: dark)' srcset='https://raw.githubusercontent.com/easyscience/assets-branding/refs/heads/master/easyutilities/logos/dark.svg'>
    <!-- default logo == light mode logo -->
    <img src='https://raw.githubusercontent.com/easyscience/assets-branding/refs/heads/master/easyutilities/logos/light.svg' alt='EasyUtilities'>
  </picture>
</p>

**EasyUtilities** is a scientific software for sharing utilities,
including reusable classes and functions, to be used across EasyScience
modules.

<!-- HOME REPOSITORY SECTION -->

**EasyUtilities** is developed as a Python library.

## Useful Links

- 📖 [Documentation](https://easyscience.github.io/utils/latest)
- 🚀
  [Getting Started](https://easyscience.github.io/utils/latest/introduction)
- 🧪 [Tutorials](https://easyscience.github.io/utils/latest/tutorials)
- 💬
  [Get in Touch](https://easyscience.github.io/utils/latest/introduction/#get-in-touch)
- 🧾
  [Citation](https://easyscience.github.io/utils/latest/introduction/#citation)
- 🤝
  [Contributing](https://easyscience.github.io/utils/latest/introduction/#contributing)
- 🐞 [Issue Tracker](https://github.com/easyscience/utils/issues)
- 💡 [Discussions](https://github.com/easyscience/utils/discussions)
- 🧑‍💻 [Source Code](https://github.com/easyscience/utils)
- ⚖️
  [License](https://raw.githubusercontent.com/easyscience/utils/refs/heads/master/LICENSE)
